@@ -150,7 +150,7 @@ int64 read_longint(struct file_list *f)
 
 void read_buf(struct file_list *f,char *buf,size_t len)
 {
-    readfd(f, buf, len);
+    readfd(f, (unsigned char*)buf, len);
 }
 
 void read_sbuf(struct file_list *f,char *buf,size_t len)
@@ -722,6 +722,7 @@ int flistDecodeBytes(struct file_list *f, unsigned char *bytes, uint32 nBytes)
     }
 }
 
+#ifndef HAVE_STRLCPY
 /* Like strncpy but does not 0 fill the buffer and always null 
  * terminates. bufsize is the size of the destination buffer.
  * 
@@ -736,6 +737,7 @@ size_t strlcpy(char *d, const char *s, size_t bufsize)
         d[len] = 0;
         return ret;
 }
+#endif
 
 /* we need to supply our own strcmp function for file list comparisons
    to ensure that signed/unsigned usage is consistent between machines. */
